﻿B4A=true
Group=Default Group
ModulesStructureVersion=1
Type=Class
Version=9.5
@EndOfDesignText@
Sub Class_Globals
	
	Private host As Activity
	
	Private open As Boolean
	
	Private screen As Panel											' Transparent foundation panel
	Private base As Panel												' Panel carrying labels
	Private info As Label												' Label carrying message
	Private later, gotit As Label								' Button labels
	
	Private h8 As Int														' One eighth height unit
	Private w8 As Int														' One eighth width unit
	
	Private msgs As List												' List of help messages
	Private current As Int											' Current message number
	Private filename As String = "helpflag"			' File holding current flag values
	
End Sub


Public Sub Initialize(caller As Activity)
	host = caller																' Client activity
	open = False
	screen.Initialize("screen")
	base.Initialize("")
	info.Initialize("")
	Dim cd As ColorDrawable
	cd.Initialize(Colors.RGB(0x20,0xA0, 0x40), 40dip)
	base.Background = cd
	later.Initialize("later")
	gotit.Initialize("gotit")
	buildMsgs
End Sub


' Set up message library. Messages are numbered from zero
Private Sub buildMsgs
	msgs.Initialize
	msgs.Add("")																										' #0
	msgs.Add("Here is some help to get you started.")								' #1
	msgs.Add("Here is some more help for a specific situation.")		' #2
End Sub

' Retrieve the current flags from internal file
Private Sub getFlags As Byte
	Dim flags(1) As Byte
	If File.Exists(File.DirInternal, filename) Then
		flags = File.ReadBytes(File.DirInternal, filename)
	Else
		flags(0) = 0
	End If
	Return flags(0)
End Sub

' TRUE if message [n] has NOT been acknowledged
Private Sub unchecked(n As Int) As Boolean
	Dim flags As Byte = getFlags
	Dim mask As Byte = 1
	mask = Bit.ShiftLeft(mask, n)
	Return (Bit.And(flags, mask) = 0)	
End Sub

' Set the required flag and save to file
Private Sub setFlag(n As Int)
	Dim flags As Byte = getFlags
	Dim b As Byte = 1
	b = Bit.ShiftLeft(b, n)
	flags = Bit.Or(flags, b)
	Dim data(1) As Byte
	data(0) = flags
	File.WriteBytes(File.DirInternal, filename, data)
End Sub

' Reset all message flags
Public Sub reset
	Dim data(1) As Byte
	data(0) = 0
	File.WriteBytes(File.DirInternal, filename, data)
End Sub

' Determine if information page is open
Public Sub isOpen As Boolean
	Return open
End Sub

' Closes the information page
Public Sub close
	If open Then
		base.RemoveAllViews												' Remove labels
		screen.RemoveAllViews						
		host.RemoveViewAt(host.NumberOfViews - 1)
		open = False
	End If
End Sub

Private Sub setupLabel(l As Label, caption As String)
	l.Color = Colors.Transparent
	l.TextColor = Colors.White
	l.TextSize = 18
	l.Gravity = Gravity.CENTER
	l.text = caption
End Sub

Private Sub makeViews
	host.AddView(screen, 0, 0, host.Width, host.Height)				' Add screen to cover client
	screen.Elevation = 8dip																		' Needed to get above button
	screen.Color = Colors.ARGB(0x50, 0x00, 0x00, 0x00)				' Partially transparent
	' Add views to construct information notice
	screen.AddView(base, host.Width / 8, host.Height / 4, 3 * host.Width / 4, host.Height / 4)
	h8 = base.Height / 8																			' Grid dimensions on base panel
	w8 = base.Width / 8
	base.AddView(info, h8, h8, base.Width - h8 - h8, 4 * h8)
	base.AddView(later, w8, 5 * h8, 2 * w8, 2 * h8)
	setupLabel(later, "Later")
	base.AddView(gotit, 5 * w8, 5 * h8, 2 * w8, 2 * h8)
	setupLabel(gotit, "Got it")
End Sub

Public Sub showMessage(n As Int)
	If isOpen Then Return																				' Just a precaution
	current = -1
	If unchecked(n) Then
		makeViews
		setupLabel(info, msgs.Get(n))
		current = n																								' Remember currently open message
		open = True		
	End If
End Sub

Private Sub gotit_click
	setFlag(current)																						' Set flag to record acknowledgement
	close																												' Record acknowledgement !!!
End Sub

Private Sub later_Click
	close	
End Sub

' Prevent contact reaching underlying activity
Private Sub screen_Touch (Action As Int, X As Float, Y As Float) As Boolean
	Return True	
End Sub